@@ -1,22 +1,15 @@
 # -*- coding: utf-8 -*-
-VERSION = (1, 0, 6)
+VERSION = (1, 0, 7)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __license__ = "Apache Version 2"
 __download_url__ = "https://github.com/downloads/briandconnelly/seeds/seeds-%s.tar.gz" % (__version__)
 
 from seeds.Action import *
+from seeds.Cell import *
 from seeds.Config import *
 from seeds.PluginManager import *
 from seeds.Resource import *
+from seeds.Topology import *
 from seeds.TopologyManager import *
 from seeds.World import *
 
-import seeds.action
-from seeds.action import *
-
-import seeds.cell
-from seeds.cell import *
-
-import seeds.topology
-from seeds.topology import *
-
